@@ -406,14 +406,14 @@ notebookutils.fs.unmountFromDriverNode <- function (mountPoint) {
 #'
 #' @examples
 #' mssparkutils.fs.getMountPath("/mnt")
-#' mssparkutils.fs.getMountPath("/mnt", "job")
+#' mssparkutils.fs.getMountPath("/mnt", " job")
 #'
 #' @param mountPoint The directory that was previously mounted.
 #' @param scope Mount point level, job or workspace, default is job.
 #'
 #' @return Empty string to mimic the local mounted path related to `mountPoint`.
 #' @export
-mssparkutils.fs.getMountPath <- function (mountPoint, scope = "job") {
+mssparkutils.fs.getMountPath <- function (mountPoint, scope = "") {
     .dummyStr
 }
 #' Gets the local path of the mount point.
@@ -427,7 +427,7 @@ mssparkutils.fs.getMountPath <- function (mountPoint, scope = "job") {
 #'
 #' @return Empty string to mimic the local mounted path related to `mountPoint`.
 #' @export
-notebookutils.fs.getMountPath <- function (mountPoint, scope = "job") {
+notebookutils.fs.getMountPath <- function (mountPoint, scope = "") {
     .dummyStr
 }
 #' Refresh workspace level mount points.
