@@ -64,10 +64,11 @@ notebookutils.notebook.help <- function (methodName = "") {
 #' @param path absolute path to the notebook, e.g. /path/to/notebook.
 #' @param timeoutSeconds timeout in seconds for the called notebook.
 #' @param arguments string map of arguments to pass to the notebook.
+#' @param workspace Workspace of the notebook.
 #'
 #' @return Empty string to mimic the exitVal set by `mssparkutils.notebook.exit`.
 #' @export
-mssparkutils.notebook.run <- function (path, timeoutSeconds = 90, arguments=NULL) {
+mssparkutils.notebook.run <- function (path, timeoutSeconds = 90, arguments=NULL, workspace="") {
     .dummyStr
 }
 #' Runs a notebook and returns its exit value. The notebook will run
@@ -81,10 +82,11 @@ mssparkutils.notebook.run <- function (path, timeoutSeconds = 90, arguments=NULL
 #' @param path absolute path to the notebook, e.g. /path/to/notebook.
 #' @param timeoutSeconds timeout in seconds for the called notebook.
 #' @param arguments string map of arguments to pass to the notebook.
+#' @param workspace Workspace of the notebook.
 #'
 #' @return Empty string to mimic the exitVal set by `mssparkutils.notebook.exit`.
 #' @export
-notebookutils.notebook.run <- function (path, timeoutSeconds = 90, arguments=NULL) {
+notebookutils.notebook.run <- function (path, timeoutSeconds = 90, arguments=NULL, workspace="") {
     .dummyStr
 }
 #' provide a way to make people can update the endpoint
@@ -116,6 +118,32 @@ mssparkutils.notebook.runMultiple <- function (pathsOrPipeline) {
 notebookutils.notebook.runMultiple <- function (pathsOrPipeline) {
     .dummyBool
 }
+
+#' Check if the DAG is correctly defined, if the syntax is correct,
+#' and if notebooks are found in the workspace without actual execution.
+#' Details can be found in mssparkutils.notebook.help("validateDAG").
+#'
+#' @param dag A list of notebook names or a complex data structure
+#' (JSON string) that meets the requirements of the
+#' com.microsoft.spark.notebook.msutils.impl.MsNotebookPipeline scala class.
+#' @return check result
+#' @export
+notebookutils.notebook.validateDAG <- function (dag) {
+    .dummyBool
+}
+#' Check if the DAG is correctly defined, if the syntax is correct,
+#' and if notebooks are found in the workspace without actual execution.
+#' Details can be found in mssparkutils.notebook.help("validateDAG").
+#'
+#' @param dag A list of notebook names or a complex data structure
+#' (JSON string) that meets the requirements of the
+#' com.microsoft.spark.notebook.msutils.impl.MsNotebookPipeline scala class.
+#' @return check result
+#' @export
+mssparkutils.notebook.validateDAG <- function (dag) {
+    .dummyBool
+}
+
 #' Create a notebook
 #'
 #' @param name Name of the notebook
@@ -175,11 +203,15 @@ notebookutils.notebook.update <- function(name, newName, description = "", works
 #' @param defaultLakehouse Default lakehouse of the notebook
 #' @param defaultLakehouseWorkspace Default lakehouse workspace of the notebook
 #' @param workspaceId Workspace id of the notebook, default to current workspace
+#' @param environmentId Environment id of the notebook, default to current environment
+#' @param environmentWorkspaceId Environment workspace id of the notebook
 #' @return The definition of the notebook
 #' @export
 notebookutils.notebook.updateDefinition <- function(name, content,
                                                     defaultLakehouse = "", defaultLakehouseWorkspace = "",
-                                                    workspaceId = "") {
+                                                    workspaceId = "",
+                                                    environmentId = "",
+                                                    environmentWorkspaceId = "") {
     .dummyBool
 }
 
